@@ -3,12 +3,12 @@
 # Copyright (c) The django-ldapdb project
 
 
-from django.conf.urls import include, url
 from django.contrib import admin
+from django.urls import include, path
 
 admin.autodiscover()
 
 urlpatterns = [
-    url(r'^admin/doc/', include('django.contrib.admindocs.urls')),
-    url(r'^admin/', admin.site.urls),
+    path('admin/doc/', include('django.contrib.admindocs.urls')),
+    path('admin/', admin.site.urls),
 ]
