@@ -3,23 +3,20 @@
 # Copyright (c) The django-ldapdb project
 
 
-import sys
-
 import ldap.filter
 from django.conf import settings
 
+from .version import __version__  # noqa
+
 
 def escape_ldap_filter(value):
-    if sys.version_info[0] < 3:
-        text_value = unicode(value)  # noqa: F821
-    else:
-        text_value = str(value)
-    return ldap.filter.escape_filter_chars(text_value)
+    return ldap.filter.escape_filter_chars(str(value))
 
 
 # Legacy single database support
 if hasattr(settings, 'LDAPDB_SERVER_URI'):
     from django import db
+
     from ldapdb.router import Router
 
     # Add the LDAP backend
