@@ -2,8 +2,7 @@
 # This software is distributed under the two-clause BSD license.
 # Copyright (c) The django-ldapdb project
 
-from __future__ import unicode_literals
-
+import django
 import ldap
 import ldap.controls
 from django.db.backends.base.base import BaseDatabaseWrapper
@@ -73,9 +72,14 @@ class DatabaseOperations(BaseDatabaseOperations):
     def no_limit_value(self):
         return -1
 
-    def sql_flush(self, style, tables, sequences, allow_cascade=False):
+    def sql_flush(self, style, tables, *, allow_cascade=False, reset_sequences=False):
         return []
 
+    if django.VERSION < (3, 1):
+        # Backwards compatibility
+        def sql_flush(self, style, tables, sequences, allow_cascade=False):  # noqa
+            return []
+
 
 class DatabaseValidation(BaseDatabaseValidation):
     pass
@@ -215,7 +219,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
     }
 
     def __init__(self, *args, **kwargs):
-        super(DatabaseWrapper, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         # Charset used for LDAP text *values*
         self.charset = "utf-8"
@@ -254,7 +258,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         }
 
     def ensure_connection(self):
-        super(DatabaseWrapper, self).ensure_connection()
+        super().ensure_connection()
 
         # Do a test bind, which will revive the connection if interrupted, or reconnect
         conn_params = self.get_connection_params()
