@@ -83,13 +83,13 @@ class Model(django.db.models.base.Model):
             ]
 
         def get_field_value(field, instance):
-            python_value = getattr(instance, field.attname)
+            python_value = getattr(instance, field.get_attname())
             return field.get_db_prep_save(python_value, connection=connection)
 
         if create:
             old = None
         else:
-            old = cls.objects.using(using).get(dn=self._saved_dn)
+            old = cls._base_manager.using(using).get(dn=self._saved_dn)
         changes = {
             field.db_column: (
                 None if old is None else get_field_value(field, old),
